part of '../core.dart';

/// @nodoc
class ZegoUIKitCoreData
    with
        ZegoUIKitCoreDataStream,
        ZegoUIKitCoreDataUser,
        ZegoUIKitCoreDataError,
        ZegoUIKitCoreDataNetworkTimestamp,
        ZegoUIKitCoreDataMedia,
        ZegoUIKitCoreDataScreenSharing {
  Timer? mixerSEITimer;

  ZegoUIKitCoreRoom room = ZegoUIKitCoreRoom('');

  StreamController<ZegoInRoomCommandReceivedData>?
      customCommandReceivedStreamCtrl;
  StreamController<ZegoNetworkMode>? networkModeStreamCtrl;

  ZegoEffectsBeautyParam beautyParam = ZegoEffectsBeautyParam.defaultParam();

  void init() {
    ZegoLoggerService.logInfo(
      'init',
      tag: 'uikit',
      subTag: 'core data',
    );

    customCommandReceivedStreamCtrl ??=
        StreamController<ZegoInRoomCommandReceivedData>.broadcast();
    networkModeStreamCtrl ??= StreamController<ZegoNetworkMode>.broadcast();
  }

  void uninit() {
    ZegoLoggerService.logInfo(
      'uninit',
      tag: 'uikit',
      subTag: 'core data',
    );

    customCommandReceivedStreamCtrl?.close();
    networkModeStreamCtrl?.close();
  }

  void clear() {
    ZegoLoggerService.logInfo(
      'clear',
      tag: 'uikit',
      subTag: 'core data',
    );

    clearStream();
    clearMedia();

    isAllPlayStreamAudioVideoMuted = false;

    remoteUsersList.clear();
    streamDic.clear();
    room.clear();
  }

  void setRoom(
    String roomID, {
    bool markAsLargeRoom = false,
  }) {
    ZegoLoggerService.logInfo(
      'set room:"$roomID", markAsLargeRoom:$markAsLargeRoom}',
      tag: 'uikit',
      subTag: 'core data',
    );

    if (roomID.isEmpty) {
      ZegoLoggerService.logError(
        'room id is empty',
        tag: 'uikit',
        subTag: 'core data',
      );
    }

    room
      ..id = roomID
      ..markAsLargeRoom = markAsLargeRoom;
  }

  Future<void> sendSEI(
    String typeIdentifier,
    Map<String, dynamic> sei,
    ZegoPublishChannel? channel,
  ) async {
    final dataJson = jsonEncode({
      streamSEIKeyUserID: localUser.id,
      streamSEIKeyTypeIdentifier: typeIdentifier,
      streamSEIKeySEI: sei,
    });
    final dataBytes = Uint8List.fromList(utf8.encode(dataJson));
    return ZegoExpressEngine.instance.sendSEI(
      dataBytes,
      dataBytes.length,
      channel: channel,
    );
  }
}
